@@ -1,3 +1,22 @@
+/*
+ *   Copyright 2009 Andrew Stromme <astromme@chatonka.com>
+ *
+ *   This program is free software; you can redistribute it and/or modify
+ *   it under the terms of the GNU Library General Public License as
+ *   published by the Free Software Foundation; either version 2, or
+ *   (at your option) any later version.
+ *
+ *   This program is distributed in the hope that it will be useful,
+ *   but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *   GNU General Public License for more details
+ *
+ *   You should have received a copy of the GNU Library General Public
+ *   License along with this program; if not, write to the
+ *   Free Software Foundation, Inc.,
+ *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+ */
+
 
 #include "session.h"
 
@@ -7,7 +26,7 @@
 #include <KApplication>
 #include <KAboutData>
 #include <KCmdLineArgs>
-#include <KDebug>
+#include <QtDebug>
 
 #include <KIO/Job>
 #include <KIO/NetAccess>
@@ -30,7 +49,7 @@ class Refresher : public QObject
     
   public slots:
     void refresh() {
-      kDebug() << "Refreshing";
+      qDebug() << "Refreshing";
       session->refreshListsFromServer();
       session->refreshTasksFromServer();
     }
